# CombinedUserDetail

Contains information about a user in the system: their profile information, their preferences, and so on. Use this to get all the high level information you need about a user in one request. The id of this object is the user's id. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithOnlyId**](MetadataWithOnlyId.md) |  | [optional] 
**status** | [**CombinedUserDetailStatus**](CombinedUserDetailStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


